@@ -1,9 +1,9 @@
 package org.acme.context.prices;
 
 import io.quarkus.test.common.QuarkusTestResource;
-import io.quarkus.test.junit.NativeImageTest;
+import io.quarkus.test.junit.QuarkusIntegrationTest;
 
-@NativeImageTest
+@QuarkusIntegrationTest
 @QuarkusTestResource(KafkaResource.class)
 public class PriceIT extends PriceTest {
 
